/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_DESKTOP_ICON_H__
#define __KIBA_DESKTOP_ICON_H__

#include <gtk/gtk.h>
#include <glib.h>

#include <kiba-cairo-utils.h>

G_BEGIN_DECLS

typedef struct _KibaDesktopIcon         KibaDesktopIcon;
typedef struct _KibaDesktopIconClass    KibaDesktopIconClass;

#define KIBA_TYPE_DESKTOP_ICON           (kiba_desktop_icon_get_type ())
#define KIBA_DESKTOP_ICON(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_DESKTOP_ICON, KibaDesktopIcon))
#define KIBA_DESKTOP_ICON_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_DESKTOP_ICON,  KibaDesktopIconClass))
#define KIBA_IS_DESKTOP_ICON(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_DESKTOP_ICON))
#define KIBA_IS_DESKTOP_ICON_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_DESKTOP_ICON))
#define KIBA_DESKTOP_ICON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_DESKTOP_ICON, KibaDesktopIconClass))

#ifdef __cplusplus
extern "C" {
#endif

typedef enum {
	KIBA_DESKTOP_TYPE_APPLICATION = 0,
	KIBA_DESKTOP_TYPE_LINK,
	KIBA_DESKTOP_TYPE_DIRECTORY,
	KIBA_DESKTOP_TYPE_REMINDER,
	KIBA_DESKTOP_TYPE_INVALID
}KibaDesktopIconType;

typedef enum {
	KIBA_DESKTOP_STATE_ACTIVE = 0,
	KIBA_DESKTOP_STATE_INACTIVE
}KibaDesktopIconState;

typedef struct {
	KibaDesktopIconType type;
	
	char  *uri;
	char  *name;
	char  *comment;
	char  *exec;
	char  *icon;
	char  *group;
}KibaDesktopEntry;

struct _KibaDesktopIcon {
	GObject                parent;
	
	GtkWidget             *object;    /* the object on the dock representing this icon */
	
	KibaDesktopEntry       entry;
	KibaDesktopIconState   state;
	CairoSurfaceData      *surface;
};

struct _KibaDesktopIconClass {
	GObjectClass parent_class;
	
	void (* activate) (KibaDesktopIcon *icon);
	void (* deactivate) (KibaDesktopIcon *icon);
	void (* file_set) (KibaDesktopIcon *icon,
			   const char      *uri);
	void (*  object_set) (KibaDesktopIcon *icon,
			      GtkWidget       *object);
};

KibaDesktopIcon* kiba_desktop_icon_new (void);

void kiba_desktop_icon_set_state (KibaDesktopIcon      *icon,
				  KibaDesktopIconState  state);

KibaDesktopIconState kiba_desktop_icon_get_state (KibaDesktopIcon *icon);

gboolean kiba_desktop_icon_set_file (KibaDesktopIcon *icon,
				     const char      *file);

char* kiba_desktop_icon_get_file (KibaDesktopIcon *icon);

void kiba_desktop_icon_set_icon (KibaDesktopIcon *icon,
				 const char      *file);

void kiba_desktop_icon_set_object (KibaDesktopIcon *icon,
				   GtkWidget       *widget);

GtkWidget* kiba_desktop_icon_get_object (KibaDesktopIcon *icon);

void kiba_desktop_icon_update_surface (KibaDesktopIcon *icon);

void kiba_desktop_icon_destroy (KibaDesktopIcon *icon);

G_END_DECLS

#endif
