/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

/**
 * KibaIconView provides a grid of widgets.
 **/

#ifndef __KIBA_ICON_VIEW_H__
#define __KIBA_ICON_VIEW_H__

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define KIBA_TYPE_ICON_VIEW           (kiba_icon_view_get_type ())
#define KIBA_ICON_VIEW(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_ICON_VIEW, KibaIconView))
#define KIBA_ICON_VIEW_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_ICON_VIEW,  KibaIconViewClass))
#define KIBA_IS_ICON_VIEW(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_ICON_VIEW))
#define KIBA_IS_ICON_VIEW_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_ICON_VIEW))
#define KIBA_ICON_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_ICON_VIEW, KibaIconViewClass))

typedef struct _KibaIconView KibaIconView;
typedef struct _KibaIconViewClass KibaIconViewClass;

typedef enum {
	KIBA_ICON_VIEW_HIDE_BEFORE = 0,
	KIBA_ICON_VIEW_SHOW,
	KIBA_ICON_VIEW_HIDE_AFTER
}KibaIconViewShowState;

typedef struct {
	GtkWidget *widget;
	GtkAllocation allocation;
	KibaIconViewShowState state;
}KibaIconViewChild;

GtkWidget* kiba_icon_view_new (void);

gint kiba_icon_view_get_columns (KibaIconView *icon_view);

void kiba_icon_view_set_columns (KibaIconView *icon_view,
                                 gint columns);

void kiba_icon_view_set_prelight_ontop (KibaIconView *icon_view,
                                        gboolean ontop);

void kiba_icon_view_set_prelightable (KibaIconView *icon_view,
                                      gboolean prelightable);

void kiba_icon_view_select_child (KibaIconView *icon_view,
                                  GtkWidget *child);

GtkWidget* kiba_icon_view_get_selected_child (KibaIconView *icon_view);

void kiba_icon_view_activate_child (KibaIconView *icon_view,
                                    GtkWidget *child);

void kiba_icon_view_show_child (KibaIconView *icon_view,
                                GtkWidget *child,
                                KibaIconViewShowState state);

void kiba_icon_view_set_sort_method (KibaIconView *icon_view,
                                     GCompareFunc method);

void kiba_icon_view_hide_first_row(KibaIconView *icon_view);

void kiba_icon_view_hide_last_row(KibaIconView *icon_view);

gint kiba_icon_view_get_active_count(KibaIconView *icon_view);

gint kiba_icon_view_get_before_count(KibaIconView *icon_view);

gint kiba_icon_view_get_after_count(KibaIconView *icon_view);

void kiba_icon_view_show_n_icons (KibaIconView *icon_view,
                                  gint n);

G_END_DECLS

#endif
