/*
 *  Copyright (C) 2006-2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Daniel Bessler <danielb@kiba-dock.org>
*/

#ifndef __KIBA_PREFS_SCHEMA_H__
#define __KIBA_PREFS_SCHEMA_H__

#include <gtk/gtk.h>
#include <glib.h>

#include <kiba-prefs.h>

G_BEGIN_DECLS

#define XML_FILE_SUFFIX ".xml"

#define XML_SECTION "section"
#define XML_SECTION_NAME "sec_name"
#define XML_SECTION_DESC "sec_desc"
#define XML_SECTION_ICON "sec_icon"
#define XML_SUBSECTION "subsection"
#define XML_SUBSECTION_NAME "sub_sec_name"
#define XML_OPTION "option"
#define XML_NAME "name"
#define XML_TITLE "title"
#define XML_ICON "icon"
#define XML_DEFAULT "default"
#define XML_TYPE "type"
#define XML_RANGE "range"
#define XML_DESCRIPTION "description"
#define DEFAULT_SUBSECTION_NAME "General"

typedef struct _KibaSchema KibaSchema;
typedef struct _SchemaSection SchemaSection;
typedef struct _SchemaSubSection SchemaSubSection;
typedef struct _SchemaMember SchemaMember;

typedef enum {
	KIBA_SCHEMA_GENERAL,
	KIBA_SCHEMA_DOCK,
	KIBA_SCHEMA_PLUGIN,
	KIBA_SCHEMA_USER
}KibaSchemaType;

/**
 * Represents one option from a xml file.
 **/
struct _SchemaMember {
	KibaSchema *schema;
	char  *section_name;
	char  *subsection_name;
	char  *widget_name;
	char  *title;
	char  *type;   /**< The option type (int,char,..) */
	char  *range;  /**< The range of value */
	char  *value;
	char  *default_value;
	char  *description;
};

struct _SchemaSubSection {
	gchar *subsection_name; /**< Subsection name */
	gchar *section_name; /**< Subsection name */
	GList *options;  /**< list of SchemaMember's */
};

struct _SchemaSection {
	gchar *section_name;  /**< Translated section name */
	gchar *section_name_untranslated; /**< Untranslated section name */
	gchar *description; /**< Section description */
	GSList *icon_list; /**< list with suggested icons */
	GList *subsections; /**< list of SchemaSubSection's */
	
	KibaSchemaType type;
};

struct _KibaSchema {
	GList *sections; /**< list of SchemaSection's */
};

KibaSchema* kiba_prefs_schema_get (KibaSchemaType type);

GList* kiba_prefs_schema_get_options(KibaSchema *schema);

void kiba_prefs_schema_set_options_from_config(KibaSchema *schema, KibaPrefsFile *file);

void kiba_prefs_schema_fini(KibaSchema *schema);

G_END_DECLS

#endif
