/*
 *  Copyright (C) 2007 Daniel Bessler <danielb@kiba-dock.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author :	Daniel Bessler <danielb@kiba-dock.org>
 *
*/

/**
 * KibaWindow is a window on the KibaScreen, sending signals if a property(icon,state,name) changes.
 **/

#ifndef __KIBA_WINDOW_H__
#define __KIBA_WINDOW_H__

#include <glib.h>
#include <gdk/gdk.h>
#include <X11/Xlib.h>

G_BEGIN_DECLS

typedef struct _KibaWindow      KibaWindow;
typedef struct _KibaWindowClass KibaWindowClass;

#define KIBA_TYPE_WINDOW           (kiba_window_get_type ())
#define KIBA_WINDOW(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), KIBA_TYPE_WINDOW, KibaWindow))
#define KIBA_WINDOW_CLASS(obj)     (G_TYPE_CHECK_CLASS_CAST ((obj), KIBA_WINDOW,  KibaWindowClass))
#define KIBA_IS_WINDOW(obj)        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), KIBA_TYPE_WINDOW))
#define KIBA_IS_WINDOW_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE ((obj), KIBA_TYPE_WINDOW))
#define KIBA_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), KIBA_TYPE_WINDOW, KibaWindowClass))

/**
 * Window state type.
 **/
typedef enum {
	KIBA_WINDOW_MAPPED,
	KIBA_WINDOW_FOCUSED,
	KIBA_WINDOW_ICONIFIED,
	KIBA_WINDOW_MAXIMIZED,
	KIBA_WINDOW_URGENT,
	KIBA_WINDOW_WITHDRAWN,
	KIBA_WINDOW_CLOSED
}KibaWindowStateFlags;

struct _KibaWindow {
	GObject          parent_instance;
	
	// TODO:  Make gdk_window and xwindow private.  The only code dealing
	// with these variables directly should be in kiba-dock/src/window.c
	GdkWindow       *gdk_window;       /**< the associated GdkWindow */
	Window           xwindow;          /**< the associated XID */
	int             state;            /**< the current KibaWindowState */
	char            *name;             /**< the current window name */
};

struct _KibaWindowClass {
	GObjectClass parent_class;
	
	/* signals */
	void (* icon_changed) (KibaWindow *window);
	void (* state_changed) (KibaWindow      *window,
				int              states_changed);
	void (* name_changed) (KibaWindow  *window,
			       const gchar *name);
};

KibaWindow* kiba_window_new (GdkWindow *gdk_window);

void kiba_window_set_minimize_restore_point(KibaWindow *window,
                                            int x,
                                            int y,
                                            int width,
                                            int height);

G_END_DECLS

#endif

